# GTTD Organizer CLI Bot
GTTD aka helper provides user Address Book, Note Book and Sorter Assist tools

## Installation

# Address Book
This program is an implementation of an address book that allows users to store and manage contacts. Users can add contacts by providing their name, phone number, email address, birthday, and home address. They can also view all contacts, search for specific contacts by name or phone number, view upcoming birthdays, and update existing contact information.

## Installation
To use this program, you'll need to have Python 3 installed on your computer.

You'll be presented with a command-line interface that allows you to interact with the address book.

### Commands
Here are the commands that are available in the program:

- add: Adds a new contact to the address book.
- show all: Shows all contacts in the address book.
- find: Searches for a contact by name or phone number.
- get bith: Shows upcoming birthdays.
- change: Changes an existing contact's information.
- del: Deleted one contact or oll contact in Address Book.
- back: Back to the general menu.


## Contributing
If you find a bug or have a suggestion for a new feature, feel free to open an issue or submit a pull request.


# Notebook

This program is a notebook implementation that allows users to store and manage their notes. Users can add notes by specifying the title name, hashtag, as well as directly the text of the note itself. They can also view all notes, search for specific notes by title or hashtag, and sort notes by the number of hashtags they contain.

# Installation

To use this program, you must have Python 3 installed on your computer.

You will be presented with a command line interface that will allow you to interact with notes.

# Commands

Here are the commands that are available in the program:

- add: Adds and saved a new note to the notebook.
- del: Deleted one note or oll notes in notebook.
- change: Changes an existing notes information.
- find: Searches for a notes by title or hashtag.
- tag sort: Sorts notes by len tags in notebook.
- show all: Shows all notes in the notebook.
- back: Back to the general menu.

# Contributing

If you find a bug or have a suggestion for a new feature, feel free to open an issue or submit a pull request.

